@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -41,7 +41,7 @@ class ServiceBinding(proto.Message):
         name (str):
             Required. Name of the ServiceBinding resource. It matches
             pattern
-            ``projects/*/locations/global/serviceBindings/service_binding_name>``.
+            ``projects/*/locations/global/serviceBindings/service_binding_name``.
         description (str):
             Optional. A free-text description of the
             resource. Max length 1024 characters.
